@@ -216,8 +216,7 @@ static void
 empathy_contact_chat_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-  empathy_dispatcher_chat_with_contact (contact, gtk_get_current_event_time (),
-      NULL, NULL);
+  empathy_dispatcher_chat_with_contact (contact, gtk_get_current_event_time ());
 }
 
 GtkWidget *
@@ -247,7 +246,7 @@ empathy_contact_audio_call_menu_item_activated (GtkMenuItem *item,
 {
 
 	empathy_call_factory_new_call_with_streams (contact, TRUE, FALSE,
-		gtk_get_current_event_time (), NULL, NULL);
+		gtk_get_current_event_time (), NULL);
 }
 
 GtkWidget *
@@ -277,7 +276,7 @@ empathy_contact_video_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
 	empathy_call_factory_new_call_with_streams (contact, TRUE, TRUE,
-		gtk_get_current_event_time (), NULL, NULL);
+		gtk_get_current_event_time (), NULL);
 }
 
 GtkWidget *
@@ -364,7 +363,6 @@ empathy_contact_file_transfer_menu_item_new (EmpathyContact *contact)
 	return item;
 }
 
-/* FIXME  we should check if the contact supports vnc stream tube */
 GtkWidget *
 empathy_contact_share_my_desktop_menu_item_new (EmpathyContact *contact)
 {
