@@ -727,34 +727,28 @@ event_room_channel_process_func (EventPriv *event)
 }
 
 static void
-event_manager_muc_invite_got_contact_cb (TpConnection *connection,
-                                         EmpathyContact *contact,
-                                         const GError *error,
-                                         gpointer user_data,
-                                         GObject *object)
+display_invite_room_dialog (EventManagerApproval *approval)
 {
-  EventManagerApproval *approval = (EventManagerApproval *) user_data;
   GtkWidget *window = empathy_main_window_dup ();
   const gchar *invite_msg;
   gchar *msg;
   TpHandle self_handle;
 
-  if (error != NULL)
-    {
-      /* FIXME: We should probably still display the event */
-      DEBUG ("Error: %s", error->message);
-      return;
-    }
-
-  approval->contact = g_object_ref (contact);
-
   self_handle = tp_channel_group_get_self_handle (approval->main_channel);
   tp_channel_group_get_local_pending_info (approval->main_channel, self_handle,
       NULL, NULL, &invite_msg);
 
-  msg = g_strdup_printf (_("%s invited you to join %s"),
-      empathy_contact_get_alias (approval->contact),
-      tp_channel_get_identifier (approval->main_channel));
+  if (approval->contact != NULL)
+    {
+      msg = g_strdup_printf (_("%s invited you to join %s"),
+          empathy_contact_get_alias (approval->contact),
+          tp_channel_get_identifier (approval->main_channel));
+    }
+  else
+    {
+      msg = g_strdup_printf (_("You have been invited to join %s"),
+          tp_channel_get_identifier (approval->main_channel));
+    }
 
   event_manager_add (approval->manager, approval->contact,
       EMPATHY_EVENT_TYPE_INVITATION, EMPATHY_IMAGE_GROUP_MESSAGE, msg,
@@ -766,6 +760,27 @@ event_manager_muc_invite_got_contact_cb (TpConnection *connection,
   g_object_unref (window);
 }
 
+static void
+event_manager_muc_invite_got_contact_cb (TpConnection *connection,
+                                         EmpathyContact *contact,
+                                         const GError *error,
+                                         gpointer user_data,
+                                         GObject *object)
+{
+  EventManagerApproval *approval = (EventManagerApproval *) user_data;
+
+  if (error != NULL)
+    {
+      DEBUG ("Error: %s", error->message);
+    }
+  else
+    {
+      approval->contact = g_object_ref (contact);
+    }
+
+  display_invite_room_dialog (approval);
+}
+
 static void
 event_manager_ft_got_contact_cb (TpConnection *connection,
                                  EmpathyContact *contact,
@@ -875,9 +890,16 @@ approve_channels (TpSimpleApprover *approver,
               DEBUG ("Have been invited to %s. Ask user if he wants to accept",
                   tp_channel_get_identifier (channel));
 
-              empathy_tp_contact_factory_get_from_handle (connection,
-                  inviter, event_manager_muc_invite_got_contact_cb,
-                  approval, NULL, G_OBJECT (self));
+              if (inviter != 0)
+                {
+                  empathy_tp_contact_factory_get_from_handle (connection,
+                      inviter, event_manager_muc_invite_got_contact_cb,
+                      approval, NULL, G_OBJECT (self));
+                }
+              else
+                {
+                  display_invite_room_dialog (approval);
+                }
 
               goto out;
             }
